pub struct Http {
pub request: HttpRequest,
pub response: HttpResponse,
pub trans_depth: usize,
}Expand description
Parsed HTTP transaction contents.
Fields
request: HttpRequestHTTP Request.
response: HttpResponseHTTP Response.
trans_depth: usizeThe pipelined depth into the connection of this transaction.
Implementations
Sourceimpl Http
impl Http
Sourcepub fn request_version(&self) -> &str
pub fn request_version(&self) -> &str
Returns the HTTP request version, or "" if it does not exist.
Sourcepub fn user_agent(&self) -> &str
pub fn user_agent(&self) -> &str
Returns the user agent string of the user agent, or "" if it does not exist.
Returns HTTP cookies sent by the client, or "" if it does not exist.
Sourcepub fn host(&self) -> &str
pub fn host(&self) -> &str
Returns the domain name of the server specified by the client, or "" if it does not exist.
Sourcepub fn request_content_length(&self) -> usize
pub fn request_content_length(&self) -> usize
Returns the size of the request body in bytes, or 0 if it does not exist.
Sourcepub fn request_content_type(&self) -> &str
pub fn request_content_type(&self) -> &str
Returns the media type of the request resource, or "" if it does not exist.
Sourcepub fn request_transfer_encoding(&self) -> &str
pub fn request_transfer_encoding(&self) -> &str
Returns the form of encoding used to transfer the request body, or "" if it does not
exist.
Sourcepub fn response_version(&self) -> &str
pub fn response_version(&self) -> &str
Returns the HTTP response version, or "" if it does not exist.
Sourcepub fn status_code(&self) -> u16
pub fn status_code(&self) -> u16
Returns the HTTP status code, or 0 if it does not exist.
Sourcepub fn status_msg(&self) -> &str
pub fn status_msg(&self) -> &str
Returns the HTTP status tet, or 0 if it does not exist.
Sourcepub fn response_content_length(&self) -> usize
pub fn response_content_length(&self) -> usize
Returns the size of the request body in bytes, or 0 if it does not exist.
Sourcepub fn response_content_type(&self) -> &str
pub fn response_content_type(&self) -> &str
Returns the media type of the response resource, or "" if it does not exist.
Sourcepub fn response_transfer_encoding(&self) -> &str
pub fn response_transfer_encoding(&self) -> &str
Returns the form of encoding used to transfer the response body, or "" if it does not
exist.